@@ -267,17 +267,16 @@ persist. I.e.
 - when the python program exits, the gnuplot process and any visible plots go
   away
 
-So if you want to write a program that just shows a plot and does nothing else,
-you MUST put some sort of blocking call after the 'plot()' and before the python
-program exits. Something as simple as the below works:
+If you want to write a program that just shows a plot, and exits when the user
+closes the plot window, you should do any of
 
-    gp.plot( ... )
-    import time
-    time.sleep(100000)
+- add 'wait':1 to the plot options dict
+- call wait() on your gnuplotlib object
+- call the global gnuplotlib.wait(), if you have a global plot
 
-The plot will then stay up until the python process is interrupted, with C-c for
-instance. This is an ugly hack, and I have ideas about improving it, but this
-hasn't been a priority so far.
+Please note that it's not at all trivial to detect if a current plot window
+exists. If not, this function will end up waiting forever, and the user will
+need to Ctrl-C.
 
 * OPTIONS
 
@@ -477,6 +476,14 @@ Don't check for failure after each gnuplot command. And don't test all the plot
 options before creating the plot. This is generally only useful for debugging or
 for more sparse 'dump' functionality.
 
+- wait
+
+When we're done asking gnuplot to make a plot, we ask gnuplot to tell us when
+the user closes the interactive plot window that popped up. The python process
+will block until the user is done looking at the data. This can also be achieved
+by calling the wait() gnuplotlib method or the global gnuplotlib.wait()
+function.
+
 ** Curve options
 
 The curve options describe details of specific curves. They are in a dict, whose
@@ -555,6 +562,12 @@ Generates 3D plots. Shorthand for 'plot(..., _3d=True)'
 
 Generates an image plot. Shorthand for 'plot(..., _with='image', tuplesize=3)'
 
+** global wait(...)
+
+Blocks until the user closes the interactive plot window. Useful for python
+applications that want blocking plotting behavior. This can also be achieved by
+calling the wait() gnuplotlib method or by adding'wait':1 to the plot options
+dict
 
 * RECIPES
 
@@ -739,7 +752,7 @@ import numpy as np
 import numpysane as nps
 
 # setup.py assumes the version is a simple string in '' quotes
-__version__ = '0.23'
+__version__ = '0.24'
 
 # note that 'with' is both a known plot and curve option
 knownPlotOptions = frozenset(('dump', 'ascii', 'log', 'notest', 'wait',
@@ -854,19 +867,19 @@ class gnuplotlib:
 
         if _data_dump_only(self.plotOptions):
             self.gnuplotProcess = None
-            return
-
-        # if we already have a gnuplot process, reset it. Otherwise make a new
-        # one
-        if hasattr(self, 'gnuplotProcess') and self.gnuplotProcess:
-            self._printGnuplotPipe( "reset\nset output\n" )
-            self._checkpoint()
         else:
-            self.gnuplotProcess = None
-            self._startgnuplot()
-            self._logEvent("_startgnuplot() finished")
+            # if we already have a gnuplot process, reset it. Otherwise make a new
+            # one
+            if hasattr(self, 'gnuplotProcess') and self.gnuplotProcess:
+                self._printGnuplotPipe( "reset\nset output\n" )
+                self._checkpoint()
+            else:
+                self.gnuplotProcess = None
+                self._startgnuplot()
+                self._logEvent("_startgnuplot() finished")
 
-        self._safelyWriteToPipe(self._plotOptionsCmds)
+        if self.plotOptions.get('terminal') != 'gp':
+            self._safelyWriteToPipe(self._plotOptionsCmds)
 
 
     def _startgnuplot(self):
@@ -1713,6 +1726,20 @@ labels with spaces in them
         return curves
 
 
+    def wait(self):
+        r'''Waits until the open interactive plot window is closed
+
+        Note: it's not at all trivial to detect if a current plot window exists.
+        If not, this function will end up waiting forever, and the user will
+        need to Ctrl-C
+
+        '''
+
+        self._printGnuplotPipe('pause mouse close\n')
+        self._logEvent("Waiting for data from gnuplot")
+        self._checkpoint('waitforever')
+
+
     def plot(self, *curves, **curveOptions_base):
         r'''Main gnuplotlib API entry point'''
 
@@ -1792,9 +1819,7 @@ labels with spaces in them
             self._safelyWriteToPipe('set output', 'output')
 
             if self.plotOptions.get('wait'):
-                self._printGnuplotPipe('pause mouse close\n')
-                self._logEvent("Waiting for data from gnuplot")
-                self._checkpoint('waitforever')
+                self.wait()
 
 
 
@@ -1938,7 +1963,6 @@ def plot3d(*curves, **jointOptions):
     plot(*curves, **jointOptions)
 
 
-
 def plotimage(*curves, **jointOptions):
 
     r'''A simple wrapper around class gnuplotlib to plot image maps
@@ -1966,6 +1990,36 @@ def plotimage(*curves, **jointOptions):
     plot(*curves, **jointOptions)
 
 
+def wait():
+    r'''Waits until the open interactive plot window is closed
+
+    SYNOPSIS
+
+        import numpy as np
+        import gnuplotlib as gp
+
+        gp.plot(np.arange(5))
+
+        # interactive plot pops up
+
+        gp.wait()
+
+        # We get here when the user closes the plot window
+
+    DESCRIPTION
+
+    This applies to the global gnuplotlib object.
+
+    It's not at all trivial to detect if a current plot window exists. If not,
+    this function will end up waiting forever, and the user will need to Ctrl-C
+
+    '''
+    global globalplot
+    if not globalplot:
+        raise Exception("There isn't a plot to wait on")
+
+    globalplot.wait()
+
 
 
 
